@@ -1,4 +1,4 @@
-require 'mocha/singleton_class'
+require 'ruby2_keywords'
 require 'mocha/expectation'
 require 'mocha/expectation_list'
 require 'mocha/invocation'
@@ -8,7 +8,6 @@ require 'mocha/method_matcher'
 require 'mocha/parameters_matcher'
 require 'mocha/argument_iterator'
 require 'mocha/expectation_error_factory'
-require 'mocha/ruby_version'
 
 module Mocha
   # Traditional mock object.
@@ -165,7 +164,7 @@ module Mocha
     # @param [Array<Symbol>] method_names names of methods to unstub.
     #
     # @example Invoking an unstubbed method causes error to be raised
-    #   object = mock('mock') do
+    #   object = mock('mock')
     #   object.stubs(:stubbed_method).returns(:result_one)
     #   object.stubbed_method # => :result_one
     #   object.unstub(:stubbed_method)
@@ -184,11 +183,11 @@ module Mocha
       end
     end
 
-    # Constrains the {Mock} instance so that it can only expect or stub methods to which +responder+ responds. The constraint is only applied at method invocation time.
+    # Constrains the {Mock} instance so that it can only expect or stub methods to which +responder+ responds publicly. The constraint is only applied at method invocation time.
     #
-    # A +NoMethodError+ will be raised if the +responder+ does not +#respond_to?+ a method invocation (even if the method has been expected or stubbed).
+    # A +NoMethodError+ will be raised if the +responder+ does not publicly +#respond_to?+ the invoked method (even if the method has been expected or stubbed).
     #
-    # The {Mock} instance will delegate its +#respond_to?+ method to the +responder+.
+    # The {Mock} instance will delegate its +#respond_to?+ method to the +responder+. However, the +include_all+ parameter is not passed through, so only public methods on the +responder+ will be considered.
     #
     # Note that the methods on +responder+ are never actually invoked.
     #
@@ -238,11 +237,11 @@ module Mocha
       self
     end
 
-    # Constrains the {Mock} instance so that it can only expect or stub methods to which an instance of the +responder_class+ responds. The constraint is only applied at method invocation time. Note that the responder instance is instantiated using +Class#allocate+.
+    # Constrains the {Mock} instance so that it can only expect or stub methods to which an instance of the +responder_class+ responds publicly. The constraint is only applied at method invocation time. Note that the responder instance is instantiated using +Class#allocate+.
     #
-    # A +NoMethodError+ will be raised if the responder instance does not +#respond_to?+ a method invocation (even if the method has been expected or stubbed).
+    # A +NoMethodError+ will be raised if the responder instance does not publicly +#respond_to?+ the invoked method (even if the method has been expected or stubbed).
     #
-    # The {Mock} instance will delegate its +#respond_to?+ method to the responder instance.
+    # The {Mock} instance will delegate its +#respond_to?+ method to the responder instance. However, the +include_all+ parameter is not passed through, so only public methods on the +responder+  will be considered.
     #
     # Note that the methods on the responder instance are never actually invoked.
     #
@@ -310,10 +309,18 @@ module Mocha
     end
 
     # @private
-    def method_missing(symbol, *arguments, &block) # rubocop:disable Style/MethodMissingSuper
+    # rubocop:disable Style/MethodMissingSuper
+    def method_missing(symbol, *arguments, &block)
+      handle_method_call(symbol, arguments, block)
+    end
+    ruby2_keywords(:method_missing)
+    # rubocop:enable Style/MethodMissingSuper
+
+    # @private
+    def handle_method_call(symbol, arguments, block)
       check_expiry
       check_responder_responds_to(symbol)
-      invocation = Invocation.new(self, symbol, *arguments, &block)
+      invocation = Invocation.new(self, symbol, arguments, block)
       if (matching_expectation_allowing_invocation = all_expectations.match_allowing_invocation(invocation))
         matching_expectation_allowing_invocation.invoke(invocation)
       elsif (matching_expectation = all_expectations.match(invocation)) || (!matching_expectation && !@everything_stubbed)
@@ -322,25 +329,14 @@ module Mocha
     end
 
     # @private
-    def respond_to_missing?(symbol, include_private = false)
+    def respond_to_missing?(symbol, _include_all)
       if @responder
-        if @responder.method(:respond_to?).arity > 1
-          @responder.respond_to?(symbol, include_private)
-        else
-          @responder.respond_to?(symbol)
-        end
+        @responder.respond_to?(symbol)
       else
         @everything_stubbed || all_expectations.matches_method?(symbol)
       end
     end
 
-    if PRE_RUBY_V19
-      # @private
-      def respond_to?(symbol, include_private = false)
-        respond_to_missing?(symbol, include_private)
-      end
-    end
-
     # @private
     def __verified__?(assertion_counter = nil)
       @expectations.verified?(assertion_counter)
@@ -391,14 +387,14 @@ module Mocha
     end
 
     def check_expiry
-      if @expired # rubocop:disable Style/GuardClause
-        Deprecation.warning(
-          "#{mocha_inspect} was instantiated in one test but it is receiving invocations within another test.",
-          ' This can lead to unintended interactions between tests and hence unexpected test failures.',
-          ' Ensure that every test correctly cleans up any state that it introduces.',
-          ' A Mocha::StubbingError will be raised in this scenario in the future.'
-        )
-      end
+      return unless @expired
+
+      sentences = [
+        "#{mocha_inspect} was instantiated in one test but it is receiving invocations within another test.",
+        'This can lead to unintended interactions between tests and hence unexpected test failures.',
+        'Ensure that every test correctly cleans up any state that it introduces.'
+      ]
+      raise StubbingError.new(sentences.join(' '), caller)
     end
   end
 end
